package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Jun 12, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Extra map[string]interface{}
type KeyPair struct {
PrivateKey []byte
PublicKey []byte
}
NewPayload creates a new token payload with a specific username and duration
Source Files
¶
Click to show internal directories.
Click to hide internal directories.